<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>MX Package Installer</source>
        <translation>MX Package Installer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Aplicacions populars</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Package</source>
        <translation>Paquet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Info</source>
        <translation>Informació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="250"/>
        <location filename="../mainwindow.ui" line="653"/>
        <location filename="../mainwindow.ui" line="975"/>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Description</source>
        <translation>Descripció </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <location filename="../mainwindow.ui" line="216"/>
        <location filename="../mainwindow.ui" line="619"/>
        <location filename="../mainwindow.ui" line="944"/>
        <location filename="../mainwindow.ui" line="1208"/>
        <source>search</source>
        <translation>cerca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="123"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Greyed out items have already been installed.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Gestiona els paquets populars&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Els que es veuen en gris ja s&apos;han instal·lat.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>Stable Repo</source>
        <translation>Dipòsit estable</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <location filename="../mainwindow.ui" line="564"/>
        <location filename="../mainwindow.ui" line="889"/>
        <location filename="../mainwindow.ui" line="1156"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filtra els paquets d&apos;acord amb el seu estat..&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="567"/>
        <location filename="../mainwindow.ui" line="571"/>
        <location filename="../mainwindow.ui" line="892"/>
        <location filename="../mainwindow.ui" line="896"/>
        <location filename="../mainwindow.cpp" line="2188"/>
        <source>All packages</source>
        <translation>Tots els paquets</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <location filename="../mainwindow.ui" line="576"/>
        <location filename="../mainwindow.ui" line="901"/>
        <location filename="../mainwindow.cpp" line="2202"/>
        <source>Installed</source>
        <translation>Instal·lat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <location filename="../mainwindow.ui" line="581"/>
        <location filename="../mainwindow.ui" line="906"/>
        <location filename="../mainwindow.cpp" line="2200"/>
        <source>Upgradable</source>
        <translation>Actualitzable</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <location filename="../mainwindow.ui" line="586"/>
        <location filename="../mainwindow.ui" line="911"/>
        <location filename="../mainwindow.ui" line="1188"/>
        <location filename="../mainwindow.cpp" line="2167"/>
        <location filename="../mainwindow.cpp" line="2204"/>
        <location filename="../mainwindow.cpp" line="2293"/>
        <source>Not installed</source>
        <translation>No instal·lat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <location filename="../mainwindow.ui" line="643"/>
        <location filename="../mainwindow.ui" line="965"/>
        <source>Package Name</source>
        <translation>Nom del paquet </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <location filename="../mainwindow.ui" line="648"/>
        <location filename="../mainwindow.ui" line="970"/>
        <location filename="../mainwindow.ui" line="1243"/>
        <source>Version</source>
        <translation>Versió </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.ui" line="680"/>
        <location filename="../mainwindow.ui" line="1002"/>
        <source>Total packages:</source>
        <translation>Paquets en total: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="307"/>
        <location filename="../mainwindow.ui" line="710"/>
        <location filename="../mainwindow.ui" line="1032"/>
        <source>Installed:</source>
        <translation>Instal·lats: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <location filename="../mainwindow.ui" line="740"/>
        <location filename="../mainwindow.ui" line="1062"/>
        <source>Upgradable:</source>
        <translation>Actualitzables: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <location filename="../mainwindow.ui" line="1313"/>
        <source>Upgrade All</source>
        <translation>Actualitza&apos;ls tots</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="378"/>
        <location filename="../mainwindow.ui" line="767"/>
        <location filename="../mainwindow.ui" line="1089"/>
        <source>Hide library and developer packages</source>
        <translation>Amaga els paquets de biblioteca i desenvolupador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <location filename="../mainwindow.ui" line="789"/>
        <location filename="../mainwindow.ui" line="1111"/>
        <source>Refresh list</source>
        <translation>Actualitza la llista</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <location filename="../mainwindow.ui" line="594"/>
        <location filename="../mainwindow.ui" line="919"/>
        <location filename="../mainwindow.ui" line="1456"/>
        <source>Greyed out items have already been installed.</source>
        <translation>Els elements en gris ja s&apos;han instal·lat. </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="473"/>
        <location filename="../mainwindow.ui" line="536"/>
        <location filename="../mainwindow.ui" line="856"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Upgradable package. Newer version available in selected repository.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Paquet Actualitzable. Hi ha una nova versió al dipòsit seleccionat.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <source>MX Test Repo</source>
        <translation>Dipòsit MX Test</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="813"/>
        <source>Debian Backports</source>
        <translation>Debian Backports</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1135"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1159"/>
        <location filename="../mainwindow.ui" line="1163"/>
        <location filename="../mainwindow.cpp" line="2148"/>
        <source>All apps</source>
        <translation>Totes les aplicacions</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1168"/>
        <location filename="../mainwindow.cpp" line="2153"/>
        <source>All runtimes</source>
        <translation>Tots els d&apos;execució</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1173"/>
        <location filename="../mainwindow.cpp" line="2158"/>
        <source>All available</source>
        <translation>Tots els disponibles</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1178"/>
        <location filename="../mainwindow.cpp" line="2146"/>
        <location filename="../mainwindow.cpp" line="2288"/>
        <source>Installed apps</source>
        <translation>Aplicacions instal·lades</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1183"/>
        <location filename="../mainwindow.cpp" line="2144"/>
        <source>Installed runtimes</source>
        <translation>Versió d&apos;execució instal·lades</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1233"/>
        <source>Short Name</source>
        <translation>Nom curt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1238"/>
        <source>Full Package Name</source>
        <translation>Nom sencer del paquet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1248"/>
        <source>Size</source>
        <translation>Mida </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1292"/>
        <source>Total items </source>
        <translation>Ítems en total</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1306"/>
        <source>Installed apps:</source>
        <translation>Aplicacions instal·lades:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1359"/>
        <source>Advanced</source>
        <translation>Avançat </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1389"/>
        <source>Total installed size:</source>
        <translation>Mida total instal·lada:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1406"/>
        <location filename="../mainwindow.ui" line="1410"/>
        <source>For all users</source>
        <translation>Per tots els usuaris</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1415"/>
        <source>For current user</source>
        <translation>Per a l&apos;usuari actual</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1433"/>
        <source>Remote (repo):</source>
        <translation>Remot (dipòsit)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1476"/>
        <location filename="../mainwindow.cpp" line="1975"/>
        <location filename="../mainwindow.cpp" line="2101"/>
        <source>Console Output</source>
        <translation>Sortida de consola</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <source>Enter</source>
        <translation>Entreu </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1493"/>
        <source>Respond here, or just press Enter</source>
        <translation>Contesteu aquí, o bé premeu Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1549"/>
        <source>Uninstall</source>
        <translation>Desinstal·la</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1556"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1572"/>
        <source>About this application</source>
        <translation>Quant a aquest programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1575"/>
        <source>About...</source>
        <translation>Quant a...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1582"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1630"/>
        <source>Display help </source>
        <translation>Mostra l&apos;ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1633"/>
        <source>Help</source>
        <translation>Ajuda </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1640"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1656"/>
        <location filename="../mainwindow.cpp" line="1878"/>
        <location filename="../mainwindow.cpp" line="2282"/>
        <location filename="../mainwindow.cpp" line="2285"/>
        <source>Install</source>
        <translation>Instal·la</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1663"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1682"/>
        <source>Quit application</source>
        <translation>Surt de l&apos;aplicació </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1685"/>
        <source>Close</source>
        <translation>Tanca </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1692"/>
        <source>Alt+C</source>
        <translation>Alt+C </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="154"/>
        <source>Uninstalling packages...</source>
        <translation>Desinstal·lant paquets...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>Running post-uninstall operations...</source>
        <translation>Executant operacions post-desinstal·lació...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Refreshing sources...</source>
        <translation>Refrescant les fonts...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <location filename="../mainwindow.cpp" line="945"/>
        <location filename="../mainwindow.cpp" line="1063"/>
        <location filename="../mainwindow.cpp" line="1179"/>
        <location filename="../mainwindow.cpp" line="1793"/>
        <location filename="../mainwindow.cpp" line="1808"/>
        <location filename="../mainwindow.cpp" line="1818"/>
        <location filename="../mainwindow.cpp" line="1946"/>
        <location filename="../mainwindow.cpp" line="1966"/>
        <location filename="../mainwindow.cpp" line="2372"/>
        <location filename="../mainwindow.cpp" line="2448"/>
        <location filename="../mainwindow.cpp" line="2475"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Hi ha hagut un problema refrescant les fonts. Algunes poden no haver subministrat actualitzacions. Per més informació comproveu:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>Cancel</source>
        <translation>Cancel·la </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Please wait...</source>
        <translation>Si us plau espereu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="751"/>
        <location filename="../mainwindow.cpp" line="769"/>
        <source>Version </source>
        <translation>Versió</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="751"/>
        <source> in stable repo</source>
        <translation>al dipòsit estable</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="753"/>
        <source>Not available in stable repo</source>
        <translation>No disponible al dipòsit estable</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <location filename="../mainwindow.cpp" line="2081"/>
        <source>Latest version </source>
        <translation>Darrera versió</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <location filename="../mainwindow.cpp" line="2081"/>
        <source> already installed</source>
        <translation>ja instal·lat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="769"/>
        <source> installed</source>
        <translation>instal·lat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="880"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>Esteu a punt d&apos;usar el dipòsit MX Test, els paquets del qual es faciliten només a efectes de prova. És possible que puguin trencar el sistema, de manera que es recomana fer una còpia de seguretat de tot el sistema, a més d&apos;instal·lar o actualitzar només un paquet cada vegada. Si us plau, comenteu els resultats al Fòrum per tal que el paquet es pugui avaluar abans de moure&apos;l al dipòsit principal.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="889"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Aneu a usar els Backports de Debian, on hi ha paquets agafats de la propera edició de Debian (anomenada &apos;testing&apos;) ajustats i recompilats per a ser usats a la versió Debian estable. No es poden comprovar tan exhaustivament com a les edicions estables de Debian i MX Linux, i es faciliten &apos;tal qual&apos;, amb el risc de que hi hagi alguna incompatibilitat amb altres components de Debian estable. Useu-ho amb compte!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="897"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>MX Linux inclou aquest dipòsit de flatpaks només per a la comoditat dels usuaris i no és responsable de la funcionalitat de cada paquet individualment. Per a més informació, consulteu flatpaks al Wiki.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Warning</source>
        <translation>Atenció </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="910"/>
        <source>Do not show this message again</source>
        <translation>No tornis a mostrar aquest missatge</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <location filename="../mainwindow.cpp" line="1063"/>
        <location filename="../mainwindow.cpp" line="1179"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>No es pot accedir a internet, no puc descarregar la llista de paquets</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="950"/>
        <source>Installing packages...</source>
        <translation>Instal·lant paquets...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="993"/>
        <source>Post-processing...</source>
        <translation>Post-processant...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1025"/>
        <source>Pre-processing for </source>
        <translation>Pre-processant per </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1038"/>
        <source>Installing </source>
        <translation>Instal·lant </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1045"/>
        <source>Post-processing for </source>
        <translation>Post-processant per </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1186"/>
        <source>Downloading package info...</source>
        <translation>Descarregant informació dels paquets...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1633"/>
        <source>Packages to be installed: </source>
        <translation>Paquets per a instal·lar: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1671"/>
        <source>Package info</source>
        <translation>Informació del paquet </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1789"/>
        <location filename="../mainwindow.cpp" line="1802"/>
        <location filename="../mainwindow.cpp" line="1815"/>
        <location filename="../mainwindow.cpp" line="1941"/>
        <location filename="../mainwindow.cpp" line="2368"/>
        <location filename="../mainwindow.cpp" line="2442"/>
        <location filename="../mainwindow.cpp" line="2469"/>
        <source>Done</source>
        <translation>Fet </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1789"/>
        <location filename="../mainwindow.cpp" line="1802"/>
        <location filename="../mainwindow.cpp" line="1815"/>
        <location filename="../mainwindow.cpp" line="1941"/>
        <location filename="../mainwindow.cpp" line="1959"/>
        <location filename="../mainwindow.cpp" line="2368"/>
        <location filename="../mainwindow.cpp" line="2442"/>
        <location filename="../mainwindow.cpp" line="2469"/>
        <source>Processing finished successfully.</source>
        <translation>S&apos;ha acabat el processat amb èxit.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1793"/>
        <location filename="../mainwindow.cpp" line="1808"/>
        <location filename="../mainwindow.cpp" line="1818"/>
        <location filename="../mainwindow.cpp" line="2372"/>
        <location filename="../mainwindow.cpp" line="2448"/>
        <location filename="../mainwindow.cpp" line="2475"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>S&apos;ha detectat un problema mentre s&apos;instal·lava; si us plau comproveu la sortida de consola.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1828"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1833"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1847"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About MX Package Installer</source>
        <translation type="vanished">Quant a l&apos;instal·lador de paquets de MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1829"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1830"/>
        <source>Package Installer for MX Linux</source>
        <translation>Instal·lador de paquets per a MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1832"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux </translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Llicència </translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Registre de canvis</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1876"/>
        <source>Reinstall</source>
        <translation>Reinstal·la</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1946"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>Hi ha un problema en desinstal·lar, vegeu la sortida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1959"/>
        <source>Success</source>
        <translation>Èxit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1966"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>He trobat un problema desinstal·lant el programa </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2057"/>
        <location filename="../mainwindow.cpp" line="2068"/>
        <source>Flatpak not installed</source>
        <translation>Flatpak no instal·lat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2057"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>El Flatpak no està instal·lat.
Voleu continuar i instal·lar-ho?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2068"/>
        <source>Flatpak was not installed</source>
        <translation>No s&apos;ha instal·lat el Flatpak</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2089"/>
        <location filename="../mainwindow.cpp" line="2108"/>
        <source>Flathub remote failed</source>
        <translation>El Flathub remot ha fallat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2089"/>
        <location filename="../mainwindow.cpp" line="2108"/>
        <source>Flathub remote could not be added</source>
        <translation>No s&apos;ha pogut afegir el Flathub remot</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2097"/>
        <source>Needs re-login</source>
        <translation>Cal reiniciar la sessió</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2097"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Potser us cal sortir i reiniciar per veure al menú els ítems instal·lats </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2280"/>
        <source>Upgrade</source>
        <translation>Actualitza</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2402"/>
        <source>Quit?</source>
        <translation>Sortir?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2403"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>El procés encara funciona, si sortiu ara el procés pot quedar en un estat inestable.&lt;p&gt;&lt;b&gt;Esteu segurs que voleu sortir del MX Package Installer?&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="14"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Gestiona remots de Flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For all users</source>
        <translation>Per a tots els usuaris</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="24"/>
        <source>For current user</source>
        <translation>Per a l&apos;usuari actual</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="30"/>
        <source>enter Flatpak remote URL</source>
        <translation>Entreu l&apos;URL del remot de Flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="33"/>
        <source>enter Flatpakref location to install app</source>
        <translation>entreu la ubicació Flatpakref per instal·lar l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="35"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Afegiu o traieu remots flatpak (dipòsits) o instal·leu aplicacions usant l&apos;URL o el camí de flatpakref</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="44"/>
        <source>Remove remote</source>
        <translation>Elimina un remot</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="49"/>
        <source>Add remote</source>
        <translation>Afegeix un remot</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="54"/>
        <source>Install app</source>
        <translation>Instal·la aplicació</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="59"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Not removable</source>
        <translation>No extraïble </translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>Flathub és el remot principal de Flatpak i no s&apos;eliminarà</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="97"/>
        <source>Error adding remote</source>
        <translation>Error afegint el remot</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="97"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>No s&apos;ha pogut afegir el remot; l&apos;ordre ha retornat un error. Comproveu l&apos;adreça del remot i torneu a provar-ho.</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Success</source>
        <translation>Èxit</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Remote added successfully</source>
        <translation>S&apos;ha afegit el remot correctament.</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Unable to get exclusive lock</source>
        <translation>No es pot bloquejar en exclusiva</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>Hi ha un altre gestor de paquets (com Synaptic o apt-get) funcionant alhora. Si us plau, tanqueu primer aquesta aplicació.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>You must run this program as root.</source>
        <translation>Cal ser usuari principal per executar aquest programa</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation type="unfinished">Llicència </translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation type="unfinished">Registre de canvis</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancel·la </translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation type="unfinished">Tan&amp;ca </translation>
    </message>
</context>
</TS>
